==> mapnik_3.0.9+ds.orig.tar.gz: mapnik-3.0.9/include/mapnik/unicode.hpp <==
/*****************************************************************************
 *
 * This file is part of Mapnik (c++ mapping toolkit)
 *
 * Copyright (C) 2015 Artem Pavlenko
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

#ifndef MAPNIK_UNICODE_HPP
#define MAPNIK_UNICODE_HPP

//mapnik
#include <mapnik/config.hpp>
#include <mapnik/util/noncopyable.hpp>
#include <mapnik/value_types.hpp>

// std
#include <cstdint>
#include <string>

struct UConverter;

namespace mapnik {

class MAPNIK_DECL transcoder : private util::noncopyable
{
public:
    explicit transcoder (std::string const& encoding);
    mapnik::value_unicode_string transcode(const char* data, std::int32_t length = -1) const;
    ~transcoder();
private:
    UConverter * conv_;
};
}

#endif // MAPNIK_UNICODE_HPP

==> mapnik_3.0.12+ds.orig.tar.gz: mapnik-3.0.12/include/mapnik/unicode.hpp <==
/*****************************************************************************
 *
 * This file is part of Mapnik (c++ mapping toolkit)
 *
 * Copyright (C) 2015 Artem Pavlenko
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

#ifndef MAPNIK_UNICODE_HPP
#define MAPNIK_UNICODE_HPP

//mapnik
#include <mapnik/config.hpp>
#include <mapnik/util/noncopyable.hpp>
#include <mapnik/value_types.hpp>

// std
#include <cstdint>
#include <string>

struct UConverter;

namespace mapnik {

class MAPNIK_DECL transcoder : private util::noncopyable
{
public:
    explicit transcoder (std::string const& encoding);
    mapnik::value_unicode_string transcode(const char* data, std::int32_t length = -1) const;
    ~transcoder();
private:
    UConverter * conv_;
};

// convinience method
void MAPNIK_DECL to_utf8(mapnik::value_unicode_string const& input, std::string & target);

}

#endif // MAPNIK_UNICODE_HPP
